==> anagram-0.0.3.tar.gz: anagram-0.0.3/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import re
import ast

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

def extract_version():
    with open('anagram/__init__.py', 'rb') as f_version:
        ast_tree = re.search(
            r'__version__ = (.*)',
            f_version.read().decode('utf-8')
        ).group(1)
        if ast_tree is None:
            raise RuntimeError('Cannot find version information')
        return str(ast.literal_eval(ast_tree))

with open('README.rst', 'rb') as f_readme:
    readme = f_readme.read().decode('utf-8')

packages = ['anagram']

version = extract_version()

setup(
    name='anagram',
    version=version,
    keywords=['anagram', 'generate', 'game'],
    description='I\'m a small script that help you get '
                'anagram use wordsmith.org.',
    long_description=readme,
    author='RayYu03',
    author_email='shiliuhuasheng@gmail.com',
    license='MIT',
    url='https://github.com/RayYu03/anagram',

    install_requires=['requests','beautifulsoup4'],
    packages=packages,

    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Web Environment',
        'Intended Audience :: Information Technology',
        'Intended Audience :: End Users/Desktop',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP',
    ],

    entry_points={
        'console_scripts': [
            'anagram = anagram.anagram:main'
        ]
    }
)

==> anagram-0.0.5.tar.gz: anagram-0.0.5/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

from __future__ import unicode_literals

import re
import ast
import io
import os


try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

def extract_version():
    with open('anagram/__init__.py', 'rb') as f_version:
        ast_tree = re.search(
            r'__version__ = (.*)',
            f_version.read().decode('utf-8')
        ).group(1)
        if ast_tree is None:
            raise RuntimeError('Cannot find version information')
        return str(ast.literal_eval(ast_tree))

long_description = io.open(
    os.path.join(os.path.dirname(__file__), 'README.rst'), encoding='utf-8').read()

packages = 'anagram',

version = extract_version()

setup(
    name='anagram',
    version=version,
    keywords=['anagram', 'generate', 'game'],
    description='I\'m a small script that help you get '
                'anagram use wordsmith.org.',
    long_description=long_description,

    author='RayYu03',
    author_email='shiliuhuasheng@gmail.com',
    license='MIT',

    url='https://github.com/RayYu03/anagram',

    install_requires=['requests','beautifulsoup4'],
    packages=packages,

    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Web Environment',
        'Intended Audience :: Information Technology',
        'Intended Audience :: End Users/Desktop',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP',
    ],

    entry_points={
        'console_scripts': [
            'anagram = anagram.anagram:main'
        ]
    }
)
